@@ -3,13 +3,13 @@ from pathlib import Path
 import typer
 from typer import Option, Argument
 
+from patterns.cli.configuration.edit import GraphConfigEditor
 from patterns.cli.helpers import random_node_id
 from patterns.cli.services.graph_path import resolve_graph_path
 from patterns.cli.services.lookup import IdLookup
 from patterns.cli.services.output import abort, prompt_path, abort_on_error
 from patterns.cli.services.output import sprint
 from patterns.cli.services.secrets import create_secret
-from patterns.configuration.edit import GraphConfigEditor
 
 create = typer.Typer(name="create", help="Create a new app or node")
 
